#include <boost/math/special_functions/owens_t.hpp>
#include "../boostmath/macros.hpp"

BINARY_BOOST_FUNCTION(owens_t, double, double);
